@@ -90,9 +90,19 @@ int main(int argc, char *argv[])
 
     a.setApplicationName("juk");
     a.setOrganizationDomain("kde.org");
+    a.setWindowIcon(QIcon::fromTheme(QStringLiteral("juk")));
     // Limit to only one instance
     KDBusService service(KDBusService::Unique);
 
+    QObject::connect(&service, &KDBusService::activateRequested, juk, [juk] {
+        if (juk->isHidden()) {
+            juk->setWindowState((juk->windowState() & ~Qt::WindowMinimized) | Qt::WindowActive);
+        }
+        juk->show();
+        juk->raise();
+        juk->activateWindow();
+    });
+
     return a.exec();
 }
 
